docstripy.rest package
======================

Submodules
----------

docstripy.rest.build\_doc module
--------------------------------

.. automodule:: docstripy.rest.build_doc
   :members:
   :undoc-members:
   :show-inheritance:

docstripy.rest.parse\_doc module
--------------------------------

.. automodule:: docstripy.rest.parse_doc
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: docstripy.rest
   :members:
   :undoc-members:
   :show-inheritance:
